@@ -1,10 +1,12 @@
 from obspy import UTCDateTime
 from obspy.geodetics import gps2dist_azimuth
 import re
-from seisloc.hypoinv import load_sum_rev,load_sum
+from seisloc.hypoinv import load_sum_evstr,load_sum_evid
 import os
 import glob
 from tqdm import tqdm
+import numpy as np
+import pandas as pd
 
 def event_sel(evid_list=[],event_dat="event.dat",event_sel="event.sel"):
     '''
@@ -122,8 +124,8 @@ def gen_dtcc(sta_list,sum_file="out.sum",work_dir="./",cc_threshold=0.7,min_link
         min_link: minumum links to form an event pair
         max_dist: maximum distance accepted to form an event pair, unit km
     '''
-    sum_rev= load_sum_rev(sum_file) # dictionary {evid: [e_lon,e_lat,e_dep,e_mag]}
-    sum_dict= load_sum(sum_file)    # dictionary {"YYYYmmddHHMMSSff":[e_lon,e_lat,e_dep,e_mag]}
+    sum_rev= load_sum_evstr(sum_file) # dictionary {evid: [e_lon,e_lat,e_dep,e_mag]}
+    sum_dict= load_sum_evid(sum_file)    # dictionary {"YYYYmmddHHMMSSff":[e_lon,e_lat,e_dep,e_mag]}
     work_dir = os.path.abspath(work_dir)
     evid_list = []                  # event list included by scc results
     to_cc_list = []                 # event list included in the ouput dt.cc.* results
@@ -386,7 +388,7 @@ def hypoDD_mag_mapper(reloc_file,out_sum):
     with open(out_sum,"r") as f_obj:
         for line in f_obj:
             event_id = int(line[136:146])
-            event_mag = int(line[122:126])*0.01
+            event_mag = int(line[123:126])*0.01
             event_mag_list[event_id]=event_mag
     f_obj.close()
     #add in the magnitude
@@ -535,7 +537,7 @@ def dd_bootstrap(base_folder="hypoDD",times=10,samp_ratio=0.75,cores=2):
     f.close()
     print("Done")
 
-def pha_subset(pha_file,loc_filter,obs_filter=8,out_path=None):
+def pha_subset(pha_file,loc_filter,obs_filter=8,out_file=None):
     """
     *.pha file is the input file for hypoDD ph2dt, this function subset the
     pha file by the boundary condition and the minimum observation condition.
@@ -550,10 +552,8 @@ def pha_subset(pha_file,loc_filter,obs_filter=8,out_path=None):
     """
 
     lon_min, lon_max, lat_min, lat_max = loc_filter
-    if out_path == None:
+    if out_file == None:
         out_file = pha_file+".st"
-    else:
-        out_file = out_path
     f = open(out_file,"w")
     f.close()
     pha_content = []
